%global xslver $(rpm -q --queryformat "%%{VERSION}" docbook-style-xsl)

Name: netatalk
Version: 4.2.3
Release: alt1

Summary: Open Source Apple Filing Protocol (AFP) File Server

License: GPLv2+
Group: Networking/Other
Url: http://netatalk.sourceforge.net

Source0: http://download.sourceforge.net/netatalk/netatalk-%version.tar.xz
Source1: netatalk.pam-system-auth
Patch0: netatalk-3.0.1-basedir.patch
Patch1: netatalk-3.1.12-alt-mysql8-transition.patch
Patch2: netatalk-3.1.12-afpstats-python3-compat.patch
Patch3: netatalk-systemd-execstartpre.patch


BuildRequires(pre): rpm-build-python3 rpm-macros-meson rpm-build-perl
BuildRequires: cracklib-devel flex libacl-devel libattr-devel libavahi-devel docbook-style-xsl python3-module-yaml python3-module-pyaml
BuildRequires: libdb4-devel libdbus-glib-devel libevent-devel libgcrypt-devel xsltproc libcups-devel libiniparser-devel
BuildRequires: libkrb5-devel libldap-devel libmysqlclient-devel libpam-devel meson cmake unicode-ucd libxslt libxslt-devel
BuildRequires: libssl-devel libtdb-devel perl-bignum perl-IO-Socket-INET6 rpm-build-perl perl-Net-DBus findutils libtdb-devel
BuildRequires:     pandoc
Requires: cracklib-words cracklib

%description
Netatalk is a freely-available Open Source AFP file server. A *NIX/*BSD
system running Netatalk is capable of serving many Macintosh clients
simultaneously as an AppleShare file server (AFP).

%package devel
Summary: Development files for %name
Requires: %name = %EVR
Group: Development/C

%description devel
This package contains libraries and header files for
developing applications that use %name.

%prep
%setup

# use system libevent instead
rm -frv libevent/

#patch0 -p1
#patch1 -p0
#patch2 -p1
#patch3 -p0

# Avoid re-running the autotools
#touch -r aclocal.m4 configure configure.ac macros/gssapi-check.m4

# fix permissions
find include \( -name '*.h' -a -executable \) -exec chmod -x {} \;

# py2 -> py3
sed -i 's|#!/usr/bin/env python|#!/usr/bin/env python3|' \
    $(find ./ \( -name '*.py' -o -name 'afpstats' \))

# Don't call systemctl daemon-reload during the build
#sed -i 's\-systemctl daemon-reload\\g' distrib/initscripts/Makefile.am

# Set RuntimeDirectory in the service file rather than use a tmpfiles.d config
#sed -E -i 's|^(ExecStart=.*)|\1\nRuntimeDirectory=lock/netatalk|' distrib/initscripts/service.systemd.tmpl

## Don't build the japanese docs and put the english docs into a subfolder
sed -i 's\install: true\install: false\' doc/translated/ja/meson.build
#sed -i 's\doc/netatalk\doc/netatalk/htmldoc\' doc/manual/meson.build

# Set RuntimeDirectory in the service file rather than use a tmpfiles.d config
sed -E -i 's|^(ExecStart=.*)|\1\nRuntimeDirectory=lock/netatalk|' distrib/initscripts/systemd.netatalk.service.in


%build


%meson  \
        -Ddefault_library=shared                                               \
        -Dwith-rpath=false                                                     \
        -Dwith-overwrite=true                                                  \
        -Dwith-tcp-wrappers=false                                              \
        -Dwith-tests=true							\
        -Dwith-cups=true                                                      \
        -Dwith-pkgconfdir-path=%{_sysconfdir}/netatalk                         \
        -Dwith-init-style=systemd	                                       \
        -Dwith-lockfile-path=%{_runtimedir}/lock/netatalk/netatalk                 \
	-Dwith-dbus-sysconf-path=%{_sysconfdir}/dbus-1/system.d                \
	-Dwith-docbook-path=%{_datadir}/sgml/docbook/xsl-stylesheets-%{xslver} \
        -Dwith-init-hooks=false



%meson_build

%install
%meson_install


# Ghost lock dir.

mkdir -p %buildroot/var/lock/netatalk

# Use specific pam conf.
mkdir -p %buildroot%_sysconfdir/pam.d
install -pm644 %SOURCE1 %buildroot%_sysconfdir/pam.d/netatalk

#mkdir -p %buildroot%_sysconfdir/dbus-1/system.d/
#cp %buildroot/usr/etc/dbus-1/system.d/netatalk-dbus.conf %buildroot%_sysconfdir/dbus-1/system.d/
find %buildroot -name '*.la' -delete -print

touch %buildroot%_sysconfdir/netatalk/afppasswd

# make rpmlint happy
#ln -sf ../README %{buildroot}/var/lib/netatalk/CNID/README

%check
#sh test/afpd/test.sh
%meson_test

%files
%doc CONTRIBUTORS.md NEWS.md COPYING COPYRIGHT INSTALL.md README.md SECURITY.md
%doc %{_defaultdocdir}/%name/htmldocs
%config(noreplace) %_sysconfdir/dbus-1/system.d/netatalk-dbus.conf
%dir %_sysconfdir/netatalk
%config(noreplace) %_sysconfdir/netatalk/afp.conf
#config(noreplace) %_sysconfdir/netatalk/dbus-session.conf
%config(noreplace) %_sysconfdir/netatalk/extmap.conf
%config(noreplace) %_sysconfdir/pam.d/netatalk
%config(noreplace) %_sysconfdir/netatalk/afppasswd
#_datadir/dbus-1/system.d/netatalk-dbus.conf
#/usr/etc/pam.d/netatalk
%_bindir/*
#exclude %_bindir/netatalk-config
%_libdir/netatalk/
%_libdir/libatalk.so.*
%_mandir/man*/*
#exclude %_mandir/man*/netatalk-config*
%_sbindir/*
%ghost %dir /var/lock/netatalk
/usr/lib/systemd/system/netatalk.service
#exclude %_localstatedir/netatalk/CNID/README
#exclude %_localstatedir/netatalk/README
#dir /var/lib/netatalk

%files devel
#_bindir/netatalk-config
#_datadir/aclocal/netatalk.m4
%_includedir/atalk/
%_libdir/libatalk.so
#_mandir/man*/netatalk-config.1*

%changelog
* Thu May 08 2025 Ilya Mashkin <oddity@altlinux.ru> 4.2.3-alt1
- 4.2.3

* Mon Mar 24 2025 Ilya Mashkin <oddity@altlinux.ru> 4.1.2-alt1
- 4.1.2

* Wed Jan 15 2025 Ilya Mashkin <oddity@altlinux.ru> 4.1.0-alt1
- 4.1.0

* Fri Dec 13 2024 Ilya Mashkin <oddity@altlinux.ru> 4.0.8-alt1
- 4.0.8

* Tue Nov 26 2024 Ilya Mashkin <oddity@altlinux.ru> 4.0.7-alt1
- 4.0.7

* Tue Nov 19 2024 Ilya Mashkin <oddity@altlinux.ru> 4.0.6-alt1
- 4.0.6

* Tue Nov 12 2024 Ilya Mashkin <oddity@altlinux.ru> 4.0.5-alt1
- 4.0.5

* Sat Nov 09 2024 Ilya Mashkin <oddity@altlinux.ru> 4.0.4-alt1
- 4.0.4

* Thu Oct 31 2024 Ilya Mashkin <oddity@altlinux.ru> 4.0.3-alt1
- 4.0.3

* Wed Sep 25 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.10-alt1
- 3.2.10

* Thu Sep 19 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.9-alt1
- 3.2.9

* Wed Sep 11 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.8-alt1
- 3.2.8
- Bump bundled WolfSSL library to stable version 5.7.2:
- (Fixed CVE-2024-1544, CVE-2024-5288, CVE-2024-5991, CVE-2024-5814)

* Thu Aug 22 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.7-alt1
- 3.2.7

* Wed Aug 07 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.5-alt1
- 3.2.5

* Mon Jul 15 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.3-alt1
- 3.2.3

* Wed Jul 10 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.2-alt2
- Name of archive fixed

* Wed Jul 10 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.2-alt1
- 3.2.2 (fixed CVE-2024-38439, CVE-2024-38440, CVE-2024-38441)

* Fri Jun 07 2024 Ilya Mashkin <oddity@altlinux.ru> 3.2.0-alt1
- 3.2.0

* Sat Oct 07 2023 Ilya Mashkin <oddity@altlinux.ru> 3.1.18-alt1
- 3.1.18 (fixed CVE-2022-22995)

* Thu Sep 28 2023 Ilya Mashkin <oddity@altlinux.ru> 3.1.17-alt1
- 3.1.17 (fixed CVE-2023-42464, CVE-2022-23121, CVE-2022-23123,
   CVE-2022-43634 and CVE-2022-45188)
- Add /etc/netatalk/afppasswd (Closes: #46445)
- Add /var/lib/netatalk (Closes: #46441)
- Add Requires: cracklib-words (Closes: #46446)

* Thu Nov 17 2022 Yuri N. Sedunov <aris@altlinux.org> 3.1.13-alt1
- 3.1.13 (fixed CVE-2021-31439, CVE-2022-23121, CVE-2022-23122,
  CVE-2022-23123, CVE-2022-23124, CVE-2022-23125 and CVE-2022-0194)

* Wed May 12 2021 Grigory Ustinov <grenka@altlinux.org> 3.1.12-alt5
- Fixed FTBFS.

* Fri Mar 26 2021 Grigory Ustinov <grenka@altlinux.org> 3.1.12-alt4
- Fixed FTBFS with -fcommon

* Mon Oct 28 2019 Andrey Bychkov <mrdrew@altlinux.org> 3.1.12-alt3
- python2 -> python3

* Tue Feb 05 2019 Nikolai Kostrigin <nickel@altlinux.org> 3.1.12-alt2
- Fix FTBFS against libmysqlclient21

* Wed Dec 26 2018 Grigory Ustinov <grenka@altlinux.org> 3.1.12-alt1
- Build new version.

* Fri Oct 12 2018 Grigory Ustinov <grenka@altlinux.org> 3.1.11-alt1
- Build new version.

* Thu Jan 25 2018 Aleksei Nikiforov <darktemplar@altlinux.org> 2.2.4-alt2
- Fixed localstatedir location.

* Sat Apr 16 2016 Dmitry V. Levin (QA) <qa_ldv@altlinux.org> 2.2.4-alt1.qa1
- NMU: rebuilt with libgcrypt.so.11 -> libgcrypt.so.20.

* Sat Dec  8 2012 Sergey Kurakin <kurakin@altlinux.org> 2.2.4-alt1
- 2.2.4
- cups support removed
- legacy AppleTalk support presents, but disabled
  in default configuration. PAP too

* Sun Apr  3 2011 Sergey Kurakin <kurakin@altlinux.org> 2.0.5-alt2
- lsb-header added
- SysVinit header corrected: don't start atalk by default
- fix DHCAST128 UAM build (buildreq)

* Mon Mar 28 2011 Michael Shigorin <mike@altlinux.org> 2.0.5-alt1.3
- devel subpackage made noarch

* Sun Mar 27 2011 Michael Shigorin <mike@altlinux.org> 2.0.5-alt1.2
- re-added lost BR:

* Mon Oct  4 2010 Sergey Kurakin <kurakin@altlinux.org> 2.0.5-alt1.1
- rebuild with new openssl (libcrypto soname change)

* Tue Dec 22 2009 Sergey Kurakin <kurakin@altlinux.org> 2.0.5-alt1
- 2.0.5:
  + fix CVE-2008-5718
  + more bugfixes

* Tue Nov 10 2009 Sergey Kurakin <kurakin@altlinux.org> 2.0.4-alt3
- rebuild with current libdb version

* Mon Jun  8 2009 Sergey Kurakin <kurakin@altlinux.org> 2.0.4-alt2
- 2.0.4 release
  + bug fixes, new configuration options, new encodings
  + timeout program removed (now is part of coreutils)
- minor fixes in initscript

* Sat Jan 31 2009 Sergey Kurakin <kurakin@altlinux.org> 2.0.4-alt1.beta2
- 2.0.4beta2 features new configuration options
  working around with MacOS 10.5 Leopard permission issues

* Fri Mar 21 2008 Sergey Kurakin <kurakin@altlinux.org> 2.0.3-alt8
- build fixed: libgnutls-devel added to BuildRequires
- libatalk.a moved from -devel to -devel-static subpackage

* Tue Jan  8 2008 Sergey Kurakin <kurakin@altlinux.org> 2.0.3-alt7
- resolved filename conflict with uniconvertor package:
  uniconv (netatalk volume encoding convertor) renamed
  to uniconv_netatalk

* Sun Dec  2 2007 Sergey Kurakin <kurakin@altlinux.org> 2.0.3-alt6
- fix initscripts to run cnid_metad daemon,
  needed for "dbd" CNID scheme to work
- replaced obsolete configure parameter "--with-did"

* Tue May 15 2007 Michael Shigorin <mike@altlinux.org> 2.0.3-alt5
- accepted spec fixes and improvements (see #11772):
  + Tue May 14 2007 Sergey Kurakin <kurakin@quittance.ru> 2.0.3-alt5
  - fixed x86_64 build
  - the same time, figured out, what's up with %_libdir stuff
  - CUPS support enabled
  - added BuildRequires: zlib-devel, needed for CUPS support
- removed what got commented out
- buildreq (added libcups-devel too)

* Fri Mar 30 2007 Michael Shigorin <mike@altlinux.org> 2.0.3-alt4
- investigated licensing question:
  + source tarball contains both GPL (COPYING) and BSD (COPYRIGHT)
  + Fedora ships as GPL
  + Mandriva ships as BSD
  + http://sourceforge.net/projects/netatalk/ mentions both
  * changed License: to "GPL, BSD" so users can choose themselves

* Tue Mar 27 2007 Sergey Kurakin <kurakin@quittance.ru> 2.0.3-alt3
- proper libdb4.3+ patch instead of invalid in 2.0.1-alt2
- license is GNU GPL in fact

* Mon Mar 26 2007 Michael Shigorin <mike@altlinux.org> 2.0.3-alt2
- built for ALT Linux Sisyphus; based on spec+patch by Sergey Kurakin
  (in its turn based on ApplianceWare 1.5.x package)
- introduced devel-static subpackage (not built by default)
- added devel subpackages Requires: (based on 1.5.3-alt13)
- replaced RH-style initscript and PAM configuration by conforming
  ones (from 1.5.3-alt13; courtesy of Alexander Bokovoy and
  Ihar Viarheichyk)
- fixed mandir directory intersections with filesystem
- minor spec cleanup
- buildreq

* Thu Mar 22 2007 Sergey Kurakin <kurakin@quittance.ru> 2.0.3-alt1.3
- just rebuild
* Sun Apr  2 2006 Sergey Kurakin <kurakin@actdesign.com> 2.0.3-alt1.2
- rebuild
* Mon Jun 13 2005 Sergey Kurakin <kurakin@actdesign.com> 2.0.3-alt1
- new version
* Sat Jun 11 2005 Sergey Kurakin <kurakin@actdesign.com> 2.0.1-alt3
- rebuild
* Sat Feb 26 2005 Sergey Kurakin <kurakin@actdesign.com> 2.0.1-alt2
- rebuild with libdb4.3
* Sun Oct 31 2004 Sergey Kurakin <kurakin@actdesign.com> 2.0.1-alt1
- new version
- added documentation
* Mon Jul 26 2004 Sergey Kurakin <kurakin@actdesign.com> 2.0-beta2
- new version

* Thu Mar 25 2004 Alexander Bokovoy <ab@altlinux.ru> 1.5.3-alt13
- Fixed:
    + Build against GCC 3.3
    + License is GNU GPL in fact
    + PAM service conforms to ALT PAM Policy now

* Fri Oct 31 2003 Alexander Bokovoy <ab@altlinux.ru> 1.5.3-alt4
- Build for ALT Linux Sisyphus
